@@ -925,140 +925,7 @@ predvol<-function(species,d,h=0,model=1) {
 				   }
 			   }
 			   
-# TODO: Add comment
-# 
-# Author: Lauri Mehtatalo and Jouni Siipilehto 27.1.2014
-			   ###############################################################################
-			   
-# Siipilehto & Meht2talo 2013. "Parameter recovery vs. parameter prediction for the Weibull distribution
-# validated for Scots pine stands in Finland". Silva Fennica 47(4), article id 1057; 
-			   
-# R-script for parameter recovery for the unweighted 2-parameter Weibull function assumed for diameter distribution
-# Assume we know one of the following mean characteristics:
-# A: D = arithmetic mean diameter i.e. the first moment
-# B: DG = basal area weighted mean diameter i.e. mean of the weighted second order Weibull distribution 
-# C: DM = arithmetic median diameter i.e. 0.5 quantile
-# D: DGM = basal area median diameter i.e. 0.5 quantile of the weighted second order Weibull distribution
-# The second moment (Dq^2) is calculated from the stem number (N_ha) and basal area per hectare (G_ha)
-			   
-# Basal area (G) is given as m^2/ha
-# The number of stems (N) is given as 1/ha
-# The mean diameter is given in cm.
-			   
-			   
-# Functions returning the Weibull scale parameter for given shape and mean diameter, 
-# for the four altermnative mean dianmeters.
-# Functions DXXX return the first derivative of these functions, 
-# but they are not currently in use and may have mistakes. 
-			   
-# A: Unweighted mean
-			   scaleDMean<-function(D,shape) {
-				   D/gamma(1/shape+1) 
-			   }
-			   
-# B Basal-area weighted mean    
-			   scaleDGMean<-function(D,shape) {
-				   D*gamma(2/shape+1)/gamma(3/shape+1) 
-			   }
-			   
-			   
-# C: Unweighted median
-			   scaleDMed<-function(D,shape) {
-				   D/(log(2)^(1/shape))   
-			   }  
-			   
-			   
-# D: Basal-area weighted median
-			   scaleDGMed<-function(D,shape) {
-				   D/(qgamma(0.5,2/shape+1))^{1/shape}      
-			   }
-			   
-# The function to be set to zero: 
-# Returns the difference of the given shape parameter and 
-# the value corresponding to given stand chaacteristics.
-# Dtype should be any of letters "A", "B", "C" and "D",
-# And specifies which type of mean or median diameter was given 
-# in argument "D".
-			   
-			   func.recweib<-function(lshape,G,N,D,Dtype, trace=FALSE) {  
-				   shape<-exp(lshape)+0.01
-				   if (Dtype=="A") {
-					   scale<-scaleDMean(D,shape)
-				   } else if (Dtype=="B") {
-					   scale<-scaleDGMean(D,shape)
-				   } else if (Dtype=="C") {
-					   scale<-scaleDMed(D,shape)
-				   } else if (Dtype=="D") {
-					   scale<-scaleDGMed(D,shape)
-				   } else stop("Dtype should be any of 'A', 'B', 'C', 'D'")
-				   
-				   sol<-40000*G/(pi*N)-scale^2*gamma(2/shape+1) 
-				   attributes(sol)$scale<-scale
-				   if (trace) cat(shape,attributes(sol)$scale,sol,"\n")
-				   sol
-			   }
-			   
-			   
-			   
-# The function for recovery of shape and scale.
-# G is Basal area, m^2/ha
-# N Number of stems, 1/ha
-# Weighted or unweighted D is mean or median diameter, cm
-# Dtype the type of the given mean diameter, given as "A", "B", "C" and "D".
-# A: The arithmetic mean 
-# B: The basal-area weighted mean
-# C: The median 
-# D: The median weighted by basal area
-# trace: if TRUE, then intermediate outbut during estimation is printed on the screen.
-# init: the initial guess for the shape parameter. 
-# If not given, the initial guesses are based on the PPM equations given 
-# in the Appendix of Siipilehto and Mehtatalo (2013).
-# 
-# The recovery is based on the solution of the equation 
-# shape(G,N,D)-shape = 0
-# Where shape(G,N,D) expresses the shape parameter of The weibull distribution
-# for the given values of the stand characteristics and shape is the estimated
-# value of the shape parameter.
-# 
-# The function returns a list with the following elements
-# shape: the shape parameter (c) in the solution
-# scale: the scale parameter (b) in the solution 
-# G, N, D, Dtype: the values of the input arguments
-# val: the value of the equation shape(G,N,D)-shape at the solution
-# 
-			   recweib<-function(G,N,D,Dtype,init=NA,trace=FALSE) {
-				   if (!sum(Dtype!=c("A","B","C","D"))) stop("Dtype should be any of 'A', 'B', 'C', 'D'")
-				   
-				   DQM<-sqrt(40000*G/(pi*N)) 
-				   
-				   if (is.na(init)) {
-					   if (Dtype=="A") {
-						   init<-1.0/log(DQM^4/D^4 + 0.1)
-					   } else if (Dtype=="B") {
-						   init<-1/log(D^2/DQM^2 + 0.05)
-					   } else if (Dtype=="C") {
-						   init<-1/log(DQM^4/D^4 + 0.1)
-					   } else if (Dtype=="D") {
-						   init<-1/log(D^2/DQM^2 + 0.05)
-					   } 
-				   }
-				   
-				   lshape<-NRnum(init=log(init-0.01), 
-						   fnlist=list(function(lshape) func.recweib(lshape,G=G,N=N,D=D,Dtype=Dtype,trace=trace)),
-						   crit=10)
-				   shape=exp(lshape$par)+0.01
-				   if (Dtype=="A") {
-					   scale<-scaleDMean(D,shape)
-				   } else if (Dtype=="B") {
-					   scale<-scaleDGMean(D,shape)
-				   } else if (Dtype=="C") {
-					   scale<-scaleDMed(D,shape)
-				   } else if (Dtype=="D") {
-					   scale<-scaleDGMed(D,shape)
-				   } 
-				   
-				   list(shape=exp(lshape$par)+0.01, scale=scale, G=G, N=N, D=D, Dtype=Dtype, val=lshape$value)
-			   }
+
 
 # The stand table example
 # The multinomial distribution
